package com.weaver.seconddev.cockpit.cmd;

import com.weaver.common.base.entity.result.WeaResult;
import com.weaver.ebuilder.datasource.api.entity.SqlParamEntity;
import com.weaver.ebuilder.datasource.api.enums.SqlParamType;
import com.weaver.framework.rpc.annotation.RpcReference;
import com.weaver.seconddev.cockpit.util.DatabaseUtils;
import com.weaver.seconddev.cockpit.util.JucailinCockpitUtils;
import com.weaver.teams.domain.user.SimpleEmployee;
import com.weaver.teams.security.context.UserContext;
import com.weaver.workflow.common.constant.list.api.DateTimeConditionEnum;
import com.weaver.workflow.common.constant.list.listdimension.RequestListInitDimensionTabEnum;
import com.weaver.workflow.common.entity.list.api.RequestListConditionApiEntity;
import com.weaver.workflow.common.entity.list.api.publicapi.RequestCountInfoPAEntity;
import com.weaver.workflow.list.api.rest.publicapi.WflRequestListRest;
import com.weaver.workrelate.performance.api.rest.RemotePerformanceService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 本年工作成果信息(按类型)
 *
 * @author shil
 * @version 1.00版本
 * @Date 2024/5/22
 */
@Component
public class CockpitWorkAchievementsCmd {
    //日志
    private final static Logger log = LoggerFactory.getLogger(CockpitWorkAchievementsCmd.class);

    @RpcReference
    public RemotePerformanceService remotePerformanceService;

    @Autowired
    private JucailinCockpitUtils jucailinCockpitUtils;

    @Autowired
    private DatabaseUtils databaseUtils;

    @RpcReference(group = "workflow")
    WflRequestListRest wflRequestListRest;


    public Map<String, Object> getDataInfo(SimpleEmployee simpleEmployee, Map<String, Object> paramMap,String tenantKey) {

        Map<String, Object> recordMap = new HashMap<String, Object>();

        List<Map<String,String>> list = new ArrayList<Map<String,String>>(100);


        String startday = "";
        if(paramMap.containsKey("startday")){
            startday = String.valueOf(paramMap.get("startday"));
        }

        String endday = "";
        if(paramMap.containsKey("endday")){
            endday = String.valueOf(paramMap.get("endday"));
        }

        String userid = "";
        Long formdata = simpleEmployee.getFormdata();
        String employeeId = simpleEmployee.getEmployeeId()+"";
        if(paramMap.containsKey("userid")){
            userid = String.valueOf(paramMap.get("userid"));
            if(StringUtils.isNotBlank(userid)){
                employeeId = userid;
            }
        }

        String one = "0";
        String oneword = "";
        String oneurl = "";
        String oneunit = "";

        String two = "0";
        String twoword = "";
        String twourl = "";
        String twounit = "";

        String three = "0";
        String threeword = "";
        String threeurl = "";
        String threeunit = "";

        String four = "0";
        String fourword = "";
        String foururl = "";
        String fourunit = "";

        try {
            //销售 0，项目 1,技术 2，其它 3
            String znlx  = getUserType(formdata+"",userid,tenantKey);
            log.error("znlx:"+znlx);

            //销售 0，项目 1,技术 2，其它 3
            if("2".equals(znlx)){
                oneword = "本年问题处理数";
                oneunit = "";
                try{
                    String pkey = "workdata.technology.wtclsl";
                    oneurl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);
                    one = getQuestInfo(startday, endday, employeeId,tenantKey);
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getQuestInfo-e:"+e);
                }

                twoword = "本年开发人天";
                twounit = "";
                try{
                    String pkey = "workdata.technology.kfrt";
                    twourl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);

                    two = getDaysInfo(startday, endday, employeeId,tenantKey);
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getDaysInfo-e:"+e);
                }

                threeword = "本年协作沟通数";
                threeunit = "";
                try{

                    String pkey = "workdata.technology.gtxz";
                    threeurl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);

                    three = getCoWorkInfo(startday,endday, employeeId,tenantKey);
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getCoWorkInfo-e:"+e);
                }

                fourword = "本年处理流程数";
                fourunit = "";
                try{
                    String pkey = "workdata.technology.cllc";
                    foururl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);

                    four = getWfInfo(simpleEmployee);
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getWfInfo-e:"+e);
                }
            }else if("1".equals(znlx)){
                oneword = "本年验收指标";
                oneunit = "万元";
                try{
                    String pkey = "workdata.project.yszb";
                    oneurl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);
                    one = "0.00";
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("yszb-e:"+e);
                }

                twoword = "本年验收金额";
                twounit = "万元";
                try{
                    String pkey = "workdata.project.ysje";
                    twourl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);

                    //项目验收信息
                    two = getYsInfo(employeeId,startday,endday);
                    log.error("two:"+two);
                    Map<String,String>twoMap = parseJe(two);
                    if(twoMap.containsKey("amount")){
                        two = twoMap.get("amount");
                    }
                    log.error("two2:"+two);
                    if(twoMap.containsKey("unit")){
                        twounit = twoMap.get("unit");
                    }
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getYsInfo-e:"+e);
                }

                threeword = "本年指标达成率";
                threeunit = "%";
                try{

                    String pkey = "workdata.project.zbdcl";
                    threeurl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);
                    three = "0.00";

                }catch (Exception e){
                    e.printStackTrace();
                    log.error("zbdcl-e:"+e);
                }

                fourword = "本年收款金额";
                fourunit = "万元";
                try{
                    String pkey = "workdata.project.skje";
                    foururl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);

                    //项目收款信息
                    four = getSkInfo(employeeId,startday,endday,tenantKey);
                    log.error("four:"+four);
                    Map<String,String> fourMap = parseJe(four);
                    if(fourMap.containsKey("amount")){
                        four = fourMap.get("amount");
                    }
                    log.error("four2:"+four);
                    if(fourMap.containsKey("unit")){
                        fourunit = fourMap.get("unit");
                    }
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getSkInfo-e:"+e);
                }

            }else if("3".equals(znlx)){
                oneword = "本年处理流程数";
                oneunit = "";
                try{
                    String pkey = "workdata.other.cllc";
                    oneurl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);
                    one = getWfInfo(simpleEmployee);
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getWfInfo-e:"+e);
                }

                twoword = "本年文档贡献度";
                twounit = "";
                try{
                    String pkey = "workdata.other.wdgx";
                    twourl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);

                    two = getDocInfo(startday,endday,employeeId,tenantKey);
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getDocInfo-e:"+e);
                }

                threeword = "本年微博填写数";
                threeunit = "";
                try{
                    String pkey = "workdata.other.wbtx";
                    threeurl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);

                    three = getDailyInfo(startday,endday,employeeId,tenantKey);
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getDailyInfo-e:"+e);
                }

                fourword = "本年沟通协作数";
                fourunit = "";
                try{
                    String pkey = "workdata.other.gtxz";
                    foururl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);

                    four = getCoWorkInfo(startday,endday,employeeId,tenantKey);
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getCoWorkInfo-e:"+e);
                }
            }else{
                oneword = "本年处理流程数";
                oneunit = "";
                try{
                    String pkey = "workdata.other.cllc";
                    oneurl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);

                    one = getWfInfo(simpleEmployee);
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getWfInfo-e:"+e);
                }

                twoword = "本年文档贡献度";
                twounit = "";
                try{
                    String pkey = "workdata.other.wdgx";
                    twourl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);

                    two = getDocInfo(startday,endday,employeeId,tenantKey);
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getDocInfo-e:"+e);
                }

                threeword = "本年微博填写数";
                threeunit = "";
                try{
                    String pkey = "workdata.other.wbtx";
                    threeurl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);

                    three = getDailyInfo(startday,endday,employeeId,tenantKey);
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getDailyInfo-e:"+e);
                }

                fourword = "本年沟通协作数";
                fourunit = "";
                try{
                    String pkey = "workdata.other.gtxz";
                    foururl =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);

                    four = getCoWorkInfo(startday,endday,employeeId,tenantKey);
                }catch (Exception e){
                    e.printStackTrace();
                    log.error("getCoWorkInfo-e:"+e);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("CockpitWorkAchievementsCmd :" + e);
        }

        Map<String,String> oneMap = new HashMap<String,String>(100);
        oneMap.put("name",oneword);
        oneMap.put("value",one);
        oneMap.put("url",oneurl);
        oneMap.put("unit",oneunit);
        list.add(oneMap);

        Map<String,String> twoMap = new HashMap<String,String>(100);
        twoMap.put("name",twoword);
        twoMap.put("value",two);
        twoMap.put("url",twourl);
        twoMap.put("unit",twounit);
        list.add(twoMap);

        Map<String,String> threeMap = new HashMap<String,String>(100);
        threeMap.put("name",threeword);
        threeMap.put("value",three);
        threeMap.put("url",threeurl);
        threeMap.put("unit",threeunit);
        list.add(threeMap);

        Map<String,String> fourMap = new HashMap<String,String>(100);
        fourMap.put("name",fourword);
        fourMap.put("value",four);
        fourMap.put("url",foururl);
        fourMap.put("unit",fourunit);
        list.add(fourMap);

        recordMap.put("datas",list);

        return recordMap;
    }

    /***
     *
     * @param startday
     * @param endday
     * @param employeeId
     * @param tenantKey
     * @return
     */
    public String getQuestInfo(String startday, String endday, String employeeId,String tenantKey) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        String quecou = "0";

        String groupId = "weaver-workflow-report-serviceworkflowreport";
        String sourceType = "LOGIC";

        try {

            Calendar calendar = Calendar.getInstance();
            int year = calendar.get(Calendar.YEAR);
            if (StringUtils.isBlank(startday)) {
                startday = year + "-01-01";
            }
            if (StringUtils.isBlank(endday)) {
                endday = sdf.format(new Date());
            }

            if (StringUtils.isBlank(employeeId)) {
                employeeId = String.valueOf(UserContext.getCurrentEmployeeId());
            }

            if (StringUtils.isNotBlank(employeeId)) {
                String dataSql =" select ifnull(sum(d.integer2),0) as devcou \n" +
                                " from wfc_form_data l\n" +
                                " inner join fto_62 d on d.id = l.dataid\n" +
                                " inner join wfc_requestbase p on p.requestid = l.requestid\n" +
                                " where d.multiresource5=?\n" +
                                " and d.date2 >=?" +
                                " and d.date2 <=?" +
                                " and d.tenant_key=?\n" +
                                " and d.is_delete='0'\n" +
                                " and l.tenant_key=?\n" +
                                " and l.delete_type=0\n" +
                                " and p.tenant_key=?\n" +
                                " and p.delete_type=0\n" +
                                " order by d.id desc ";

                log.info("getQuestInfo-dataSql:" + dataSql);

                List<String> strlist = new ArrayList<>(100);
                strlist.add(employeeId);
                strlist.add(startday);
                strlist.add(endday);
                strlist.add(tenantKey);
                strlist.add(tenantKey);
                strlist.add(tenantKey);

                List<SqlParamEntity> sqlparam = databaseUtils.getSqlParamEntity(strlist);

                Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql,sqlparam);
                List<Map<String,Object>> recordList = databaseUtils.getDataSourceList(result);
                log.error("recordList:"+recordList.size());
                if(recordList.size()>0){
                    quecou = String.valueOf(recordList.get(0).get("devcou"));
                }
                log.error("quecou:"+quecou);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("getQuestInfo-e:" + e);
        }
        return quecou;
    }


    /**
     * 获取人员类型
     * @param formdata
     * @param userid
     * @param tenantKey
     * @return
     */
    public String getUserType(String formdata,String userid,String tenantKey) {
        String sourceType = "LOGIC";
        String userType = "3";
        try{
            if(StringUtils.isNotBlank(userid)){

                String groupId ="weaver-ebuilder-form-service";

                String dataSql =" select formdata " +
                                " from eteams.employee a   " +
                                " where a.id = ?   " +
                                " and a.tenant_key = ?  " ;

                log.error("getUserType--dataSql:" + dataSql);

                List<SqlParamEntity> sqlparam = new ArrayList<SqlParamEntity>();
                SqlParamEntity sqlParamEntity = new SqlParamEntity();
                sqlParamEntity.setParamType(SqlParamType.LONG);
                sqlParamEntity.setValue(userid);
                sqlparam.add(sqlParamEntity);

                sqlParamEntity = new SqlParamEntity();
                sqlParamEntity.setParamType(SqlParamType.VARCHAR);
                sqlParamEntity.setValue(tenantKey);
                sqlparam.add(sqlParamEntity);

                Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlparam);
                List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
                if (recordList.size()>0) {
                    formdata = String.valueOf(recordList.get(0).get("formdata"));
                }
            }

            String field69 = "";
            if(StringUtils.isNotBlank(formdata)){
                String pkey = "field69.groupId";
                String groupId =  jucailinCockpitUtils.getUfPropData(pkey,tenantKey);
                log.error("groupId:"+groupId);
                String sql =" select field69 from eteams.Hrmemployeedefined where form_data_id = ?" ;
                log.error("getUserType--sql:"+sql);
                List<SqlParamEntity> sqlparam = new ArrayList<SqlParamEntity>();
                SqlParamEntity sqlParamEntity = new SqlParamEntity();
                sqlParamEntity.setParamType(SqlParamType.LONG);
                sqlParamEntity.setValue(formdata+"");
                sqlparam.add(sqlParamEntity);
                Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, sql,sqlparam);
                List<Map<String,Object>> recordList = databaseUtils.getDataSourceList(result);
                if(recordList.size()>0){
                    // 销售 0，项目 1,技术 2，其它 3
                    field69 = String.valueOf(recordList.get(0).get("field69"));
                }
            }

            log.error("field69:"+field69);
            if(StringUtils.isNotBlank(field69)){
                switch (field69){
                    case "1":
                        userType = "0";
                        break;
                    case "2":
                        userType = "1";
                        break;
                    case "3":
                        userType = "2";
                        break;
                    default:
                        userType = "3";
                }
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("getUserType-e:"+e);
        }
        return userType;
    }

    /***
     *
     * @param startday
     * @param endday
     * @param employeeId
     * @return
     */
    public String getDaysInfo(String startday, String endday, String employeeId,String tenantKey) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

        String devcou = "0";

        String groupId = "weaver-workflow-report-serviceworkflowreport";
        String sourceType = "LOGIC";

        try {
            Calendar calendar = Calendar.getInstance();
            int year = calendar.get(Calendar.YEAR);

            if (StringUtils.isBlank(startday)) {
                startday = year + "-01-01";
            }
            if (StringUtils.isBlank(endday)) {
                endday = sdf.format(new Date());
            }
            if (StringUtils.isBlank(employeeId)) {
                employeeId = String.valueOf(UserContext.getCurrentEmployeeId());
            }

            if (StringUtils.isNotBlank(employeeId)) {
                String dataSql =" select count(1) as devcou \n" +
                                " from wfc_form_data l\n" +
                                " inner join fto_83 d on d.id = l.dataid\n" +
                                " inner join wfc_requestbase p on p.requestid = l.requestid\n" +
                                " where d.mutiresource= ?\n" +
                                " and d.xsjfrq >= ?" +
                                " and d.xsjfrq <= ?" +
                                " and d.tenant_key= ?\n" +
                                " and d.is_delete='0'\n" +
                                " and l.tenant_key=?\n" +
                                " and l.delete_type=0\n" +
                                " and p.tenant_key=?\n" +
                                " and p.delete_type=0\n" +
                                " order by d.id desc ";

                log.error("getDaysInfo-dataSql:" + dataSql);

                List<String> strlist = new ArrayList<>(100);
                strlist.add(employeeId);
                strlist.add(startday);
                strlist.add(endday);
                strlist.add(tenantKey);
                strlist.add(tenantKey);
                strlist.add(tenantKey);
                List<SqlParamEntity> sqlparam = databaseUtils.getSqlParamEntity(strlist);
                Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql,sqlparam);
                List<Map<String,Object>> recordList = databaseUtils.getDataSourceList(result);
                log.error("recordList:"+recordList.size());

                if(recordList.size()>0){
                    devcou = String.valueOf(recordList.get(0).get("devcou"));
                }
                log.error("getDaysInfo-devcou:"+devcou);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("getDaysInfo-e:" + e);
        }
        return devcou;
    }

    /**
     * 本年沟通协作数
     *
     * @param
     * @return
     */
    public String getCoWorkInfo(String startday, String endday, String employeeId,String tenantKey) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

        String groupId = "weaver-cowork-service";
        String sourceType = "LOGIC";
        String count = "0";
        try {

            Calendar calendar = Calendar.getInstance();
            int year = calendar.get(Calendar.YEAR);

            if (StringUtils.isBlank(startday)) {
                startday = year + "-01-01";
            }
            if (StringUtils.isBlank(endday)) {
                endday = sdf.format(new Date());
            }
            if (StringUtils.isBlank(employeeId)) {
                employeeId = String.valueOf(UserContext.getCurrentEmployeeId());
            }

            String sql =" select count(1) as count from cw_content " +
                        " where CREATOR=?\n" +
                        " and left(create_time,10)>=? " +
                        " and left(create_time,10)<= ?" +
                        " and tenant_key = ?" +
                        " and delete_type = 0 ";

            log.error("getInteractInfo sql:" + sql);

            List<String> strlist = new ArrayList<>(100);
            strlist.add(employeeId);
            strlist.add(startday);
            strlist.add(endday);
            strlist.add(tenantKey);

            List<SqlParamEntity> sqlparam = databaseUtils.getSqlParamEntity(strlist);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, sql, sqlparam);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("recordList:"+recordList.size());

            if (recordList.size() > 0) {
                count = String.valueOf(recordList.get(0).get("count"));
            }
            log.error("getCoWorkInfo-count:"+count);
        }catch (Exception e){
            e.printStackTrace();
            log.error("getCoWorkInfo-e:"+e.getMessage());
        }
        return count;
    }


    /**
     * 本年流程处理数量
     *
     * @param
     * @return
     */
    public String getWfInfo(SimpleEmployee employee) {
        String wfcount = "0";
        try{
            RequestListConditionApiEntity conditionEntity = new RequestListConditionApiEntity();
            conditionEntity.setOperatedate(DateTimeConditionEnum.CURRENT_YEAR);
            WeaResult<RequestCountInfoPAEntity> requestCountInfo = wflRequestListRest.getRequestCountByTabId(employee, RequestListInitDimensionTabEnum.DONE_FLOWALL.getTabid(), conditionEntity);
            int code = requestCountInfo.getCode();
            if(code == 200){
                RequestCountInfoPAEntity requestCountInfoPAEntity = requestCountInfo.getData();
                Long count = requestCountInfoPAEntity.getCount();
                wfcount = count+"" ;
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("getWfInfo-e:" + e);
        }
        return wfcount;
    }


    /***
     *
     * @param employeeId
     * @param startday
     * @param endday
     * @return
     */
    public String getSkInfo(String employeeId,String startday,String endday,String tenantKey) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";

        String skje = "0.00";
        try {

            Calendar calendar = Calendar.getInstance();
            int year = calendar.get(Calendar.YEAR);

            if(StringUtils.isBlank(startday)){
                startday = year+"-01-01";
            }
            if(StringUtils.isBlank(endday)){
                endday = sdf.format(new Date());
            }

            if (StringUtils.isBlank(employeeId)) {
                employeeId = String.valueOf(UserContext.getCurrentEmployeeId());
            }

            log.error("employeeId2:"+employeeId);
            log.error("startday2:"+startday);
            log.error("endday2:"+endday);

            if(StringUtils.isNotBlank(employeeId)){
                String sql =" SELECT \n" +
                            "   convert(ifnull(sum(cast(t1.skje as decimal(18,2))),0),char) as skje " +  //收款金额
                            " from uf_jxhs_skmx t1\n" +
                            " left join uf_jxhs_zxhtzb t2 ON t1.hth = t2.hth AND t2.hth != '' AND t2.hth IS NOT NULL \n" +
                            " left join ebdf_physical_data epd on t1.id = epd.form_data_id  and epd.delete_type = 0 \n" +
                            " WHERE t1.skje != 0 \n" +
                            " and t1.skje IS NOT NULL " +
                            " and t1.xshsny >= ? and t1.xshsny <=? "+
                            " and (" +
                            "   ? IN ( 2, 27, 166, 10285, 11661, 300, 876, 3593, 1416, 1647, 1844,3044480226941419013,794508876297846787 ) \n" +
                            "   or cast(t1.xsjl AS decimal(25,0)) in( \n" +
                            "       SELECT cid AS id FROM eteams.emp_link WHERE pid = ?  and RELATION in ('othersenior','senior') \n" +
                            "       UNION  " +
                            "       SELECT id FROM eteams.employee WHERE id =  ? " +
                            "   )\n" +
                            "   or cast(t1.kfry AS decimal(25,0)) in(\n" +
                            "       SELECT cid AS id FROM eteams.emp_link WHERE pid =  ?  and RELATION in ('othersenior','senior') \n" +
                            "       UNION  " +
                            "       SELECT id FROM eteams.employee WHERE id =  ? " +
                            "   )\n" +
                            "   or cast(t1.qdjl AS decimal(25,0)) in(\n" +
                            "       SELECT cid AS id FROM eteams.emp_link WHERE pid =  ?  and RELATION in ('othersenior','senior') \n" +
                            "       UNION  " +
                            "       SELECT id FROM eteams.employee WHERE id =  ? " +
                            "   )\n" +
                            "   or cast(t1.xmjl AS decimal(25,0)) in(\n" +
                            "       SELECT cid AS id FROM eteams.emp_link WHERE pid =  ? and RELATION in ('othersenior','senior') \n" +
                            "       UNION  " +
                            "       SELECT id FROM eteams.employee WHERE id =  ? " +
                            "   )\n" +
                            " )\n" +
                            " order by t1.id " ;

                log.error("getSkInfo-sql:"+sql);

                List<String> strlist = new ArrayList<>(100);
                strlist.add(startday);
                strlist.add(endday);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                List<SqlParamEntity> sqlparam = databaseUtils.getSqlParamEntity(strlist);
                Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, sql,sqlparam);
                List<Map<String,Object>> recordList = databaseUtils.getDataSourceList(result);
                log.error("recordList:"+recordList.size());

                if(recordList.size()>0){
                    skje = String.valueOf(recordList.get(0).get("skje"));
                    log.error("skje:"+skje);
                }
                log.error("skje2:"+skje);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("getSkInfo-e:"+e);
        }
        return skje;
    }

    /***
     *
     * @param employeeId
     * @param startday
     * @param endday
     * @return
     */
    public String getYsInfo(String employeeId,String startday,String endday){

        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";

        String htzje = "0.00" ;

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        try {
            Calendar calendar = Calendar.getInstance();
            int year = calendar.get(Calendar.YEAR);

            if(StringUtils.isBlank(startday)){
                startday = year+"-01-01";
            }
            if(StringUtils.isBlank(endday)){
                endday = sdf.format(new Date());
            }

            if (StringUtils.isBlank(employeeId)) {
                employeeId = String.valueOf(UserContext.getCurrentEmployeeId());
            }

            log.error("employeeId:"+employeeId);
            log.error("startday:"+startday);
            log.error("endday:"+endday);


            if(StringUtils.isNotBlank(employeeId)){
                String sql =" select convert(ifnull(sum(cast(t1.htzje as decimal(18,2))),0),char) as htzje" +
                            " from uf_jxhs_xmys t1 \n" +
                            " where t1.ysrq>=? and t1.ysrq<=? \n" +
                            " and ( t1.qyjl = ? "+
                            "       or t1.qyjl in (select cid  from eteams.EMP_LINK where RELATION in ('othersenior','senior') and pid= ?)\n" +
                            "       or t1.ysry = ?\n" +
                            "       or t1.ysry in (select cid  from eteams.EMP_LINK where RELATION in ('othersenior','senior') and pid= ?)\n" +
                            "       or t1.dqfzr = ?\n" +
                            "       or t1.dqfzr in (select cid  from eteams.EMP_LINK where RELATION in ('othersenior','senior') and pid= ?)\n" +
                            "       or t1.tdjl = ?\n" +
                            "       or t1.tdjl in (select cid  from eteams.EMP_LINK where RELATION in ('othersenior','senior') and pid= ?)\n" +
                            "       or t1.tdfzr = ?\n" +
                            "       or t1.tdfzr in (select cid  from eteams.EMP_LINK where RELATION in ('othersenior','senior') and pid= ?)\n" +
                            "       or t1.jgfzr = ?\n" +
                            "       or t1.jgfzr in (select cid  from eteams.EMP_LINK where RELATION in ('othersenior','senior') and pid= ?)\n" +
                            "       or t1.dqzj = ?\n" +
                            "       or t1.dqzj in (select cid  from eteams.EMP_LINK where RELATION in ('othersenior','senior') and pid= ?) " +
                            " ) " ;

                log.error("getYsInfo-sql:"+sql);

                List<String> strlist = new ArrayList<>(100);
                strlist.add(startday);
                strlist.add(endday);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);
                strlist.add(employeeId);

                List<SqlParamEntity> sqlparam = databaseUtils.getSqlParamEntity(strlist);
                Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId,sql,sqlparam);
                List<Map<String,Object>> recordList = databaseUtils.getDataSourceList(result);
                log.error("recordList:"+recordList.size());
                if(recordList.size()>0){
                    htzje = String.valueOf(recordList.get(0).get("htzje"));
                    log.error("htzje:"+htzje);
                }
                log.error("htzje2:"+htzje);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("getYsInfo-e:"+e.getMessage());
        }
        return htzje;
    }


    /**
     * 本年文档创建贡献数
     * @param
     * @return
     */
    public String getDocInfo(String startday,String endday,String employeeId,String tenantKey) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

        String groupId = "weaver-doc-service";
        String sourceType = "LOGIC";

        String count = "0";
        try{
            Calendar calendar = Calendar.getInstance();
            int year = calendar.get(Calendar.YEAR);

            if(StringUtils.isBlank(startday)){
                startday = year+"-01-01";
            }
            if(StringUtils.isBlank(endday)){
                endday = sdf.format(new Date());
            }

            if (StringUtils.isBlank(employeeId)) {
                employeeId = String.valueOf(UserContext.getCurrentEmployeeId());
            }

            if(StringUtils.isNotBlank(employeeId)){
                String sql = " select count(1) as count " +
                        " from document " +
                        " where CREATOR=?\n" +
                        " and left(create_time,10)>=? " +
                        " and left(create_time,10) <= ?" ;

                log.error("getDocInfo-sql:"+sql);
                List<String> strlist = new ArrayList<>(100);
                strlist.add(employeeId);
                strlist.add(startday);
                strlist.add(endday);

                List<SqlParamEntity> sqlparam = databaseUtils.getSqlParamEntity(strlist);

                Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, sql,sqlparam);
                List<Map<String,Object>> recordList = databaseUtils.getDataSourceList(result);
                log.error("recordList:"+recordList.size());
                if(recordList.size()>0){
                    count = String.valueOf(recordList.get(0).get("count"));
                }
                log.error("getDocInfo-count:"+count);
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("getDocInfo-e:"+e);
        }
        return count;
    }

    /***
     *
     * @param startday
     * @param endday
     * @param employeeId
     * @param tenantKey
     * @return
     */
    public String getDailyInfo(String startday,String endday,String employeeId,String tenantKey) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

        String groupId = "weaver-blog-service";
        String sourceType = "LOGIC";
        String count = "0";
        try{
            Calendar calendar = Calendar.getInstance();
            int year = calendar.get(Calendar.YEAR);

            if(StringUtils.isBlank(startday)){
                startday = year+"-01-01";
            }
            if(StringUtils.isBlank(endday)){
                endday = sdf.format(new Date());
            }

            if (StringUtils.isBlank(employeeId)) {
                employeeId = String.valueOf(UserContext.getCurrentEmployeeId());
            }

            if(StringUtils.isNotBlank(employeeId)){
                String sql =" select count(1) as count\n" +
                            "    from blog " +
                            "    where creator=?\n" +
                            "    and left(BLOG_TIME,10) >=?\n" +
                            "    and left(BLOG_TIME,10) <=?\n" +
                            "    and type='blog'\n" +
                            "    and TENANT_KEY = ?\n" +
                            "    and MODULE = 'blog'\n" +
                            "    and DELETE_TYPE = 0\n" +
                            "    and CONTENT is not null" ;

                log.error("getDailyInfo-sql:"+sql);
                List<String> strlist = new ArrayList<>(100);
                strlist.add(employeeId);
                strlist.add(startday);
                strlist.add(endday);
                strlist.add(tenantKey);

                List<SqlParamEntity> sqlparam = databaseUtils.getSqlParamEntity(strlist);

                Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, sql,sqlparam);
                List<Map<String,Object>> recordList = databaseUtils.getDataSourceList(result);
                if(recordList.size()>0){
                    count = String.valueOf(recordList.get(0).get("count"));
                }
                log.error("getDailyInfo-count:"+count);
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("getDailyInfo-e:"+e);
        }
        return count;
    }


    /***
     *
     * @param value
     * @return
     */
    public Map<String,String> parseJe(String value){
        Map<String,String> dataMap = new HashMap<String,String>();
        String amount = "0.00";
        String unit = "万元";
        try{
            if(StringUtils.isNotBlank(value)){
                BigDecimal dividend = new BigDecimal(value); // 被除数
                if(dividend.doubleValue()>100000000){
                    BigDecimal divisor = new BigDecimal("100000000");  // 除数
                    BigDecimal result = dividend.divide(divisor, 2, RoundingMode.HALF_UP);  // 设置小数点后两位，并进行四舍五入
                    amount = result.toString();
                    unit = "亿元";
                }else if(dividend.doubleValue()>10000){
                    BigDecimal divisor = new BigDecimal("10000");  // 除数
                    BigDecimal result = dividend.divide(divisor, 2, RoundingMode.HALF_UP);  // 设置小数点后两位，并进行四舍五入
                    amount = result.toString();
                    unit = "万元";
                }
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("parseJe-e:"+e);
        }
        dataMap.put("unit",unit);
        dataMap.put("amount",amount);
        return dataMap;
    }

}
